@@ -12,8 +12,9 @@ test_that("armadillo.create_project creates a folder", {
   stub_request("put", uri = "https://test.nl/access/projects") %>%
     wi_th(
       headers = list(
-      "Accept" = "application/json, text/xml, application/xml, */*",
-      "Content-Type" = "application/json"),
+                     "Accept" =
+                       "application/json, text/xml, application/xml, */*",
+                     "Content-Type" = "application/json"),
       body = "{\"name\":\"project\"}"
     ) %>%
     to_return(
